@@ -5,9 +5,10 @@ from enum import Enum
 from typing import List, Any, Optional, Union, Tuple, Callable, Dict
 
 from easyshare.logging import get_logger
+from easyshare.utils import lexer
 from easyshare.utils.json import j
 from easyshare.utils.str import unprefix
-from easyshare.utils.types import to_int, list_wrap
+from easyshare.utils.types import to_int, list_wrap, is_list, is_str, to_float
 
 log = get_logger(__name__)
 
@@ -81,7 +82,7 @@ class Args:
         return self.has_option(item)
 
     @staticmethod
-    def parse(args: List[str], *,
+    def parse(args: Union[str, List[str]], *,
               positionals_spec: OptionParams = None,
               options_spec: List[Option] = None,
               continue_parsing_hook: Optional[Callable[[str, ArgType, int, 'Args', List[str]], bool]] = None):
@@ -142,6 +143,14 @@ class Args:
         """
         return self._unparsed or default
 
+    def get_unparsed_arg(self, default=None) -> Optional[str]:
+        """
+        Returns the unparsed arg by joinining the unparsed args.
+        (there will be unparsed args only if
+        continue_parsing_hook stopped the parsing)
+        """
+        return " ".join(self.get_unparsed_args(default=[])) or default
+
     def clone(self) -> 'Args':
         return Args(
             parsed=copy.deepcopy(self._parsed),
@@ -172,13 +181,13 @@ class ArgsParser:
 
     def parse(self) -> Args:
         """
-                Parses the given arguments using the 'positionals_spec' and 'options_spec'
-                for parse positionals and options properly.
-                The 'continue_parsing_hook' is a call that can be used for interrupt
-                the parsing, by returning False
-                """
+        Parses the given arguments using the 'positionals_spec' and 'options_spec'
+        for parse positionals and options properly.
+        The 'continue_parsing_hook' is a call that can be used for interrupt
+        the parsing, by returning False
+        """
         log.d("Starting arguments parsing")
-        log.d("Known options: %s", [o[0] for o in self._options_spec])
+        log.d(f"Known options: {[o[0] for o in self._options_spec]}")
 
         # For keep idempotent
         self._cursor = 0
@@ -192,7 +201,7 @@ class ArgsParser:
             while self._cursor < len(self._args):
                 arg = self._args[self._cursor]
 
-                log.d("Inspecting argument %s", arg)
+                log.d(f"Inspecting argument {arg}")
 
                 # Check whether we can go further
                 if ArgsParser._is_option(arg):
@@ -202,7 +211,7 @@ class ArgsParser:
 
                 if self._continue_parsing_hook:
                     cont = self._continue_parsing_hook(arg, argtype, self._cursor, ret, self._positionals)
-                    log.d("continue: %s", cont)
+                    log.d(f"continue: {cont}")
 
                     if not cont:
                         log.i("Parsed stopped by the continue hook")
@@ -244,7 +253,7 @@ class ArgsParser:
                         chain_idx += 1
                 else:
                     # Positional parg
-                    log.d("Considering '%s' as positional parameter", arg)
+                    log.d(f"Considering '{arg}' as positional parameter")
                     # Add as it is (non parsed) for now,
                     # will parse all the positionals at the end
                     self._positionals.append(arg)
@@ -252,8 +261,8 @@ class ArgsParser:
                 self._cursor += 1
 
             # Parse positionals
-            log.d("%d unparsed args w/o positional: %s", len(self._unparsed), self._unparsed)
-            log.d("%d positional arguments: %s", len(self._positionals), self._positionals)
+            log.d(f"{len(self._unparsed)} unparsed args w/o positional: {self._unparsed}")
+            log.d(f"{len(self._positionals)} positional arguments: {self._positionals}")
 
             # Create the positionals bucket (None), parse the positionals
             # using the positions_spec and add to the bucket
@@ -265,12 +274,12 @@ class ArgsParser:
             )
 
             if parsed_positionals_count != len(self._positionals):
-                log.w("There will be %d unparsed positionals arguments",
-                      len(self._positionals) - parsed_positionals_count)
+                log.w(f"There will be {len(self._positionals) - parsed_positionals_count} "
+                      f"unparsed positionals arguments")
 
             # Eventually add the remaining to the unparsed
             self._unparsed += self._positionals[parsed_positionals_count:]
-            log.d("%d unparsed args: %s", len(self._unparsed), self._unparsed)
+            log.d(f"{len(self._unparsed)} unparsed args: {self._unparsed}")
             return ret
 
         except Exception as err:
@@ -283,15 +292,15 @@ class ArgsParser:
         associated with an option alias in 'opt_alias'
         """
 
-        log.d("get_bucket (%s)", opt_alias)
+        log.d(f"get_bucket ({opt_alias})")
 
         for option_spec in self._options_spec:
             opt_aliases, opt_params = option_spec
-            log.d("Inspecting aliases: %s", opt_aliases)
+            log.d(f"Inspecting aliases: {opt_aliases}")
             if opt_alias in opt_aliases:
 
                 # Found an alias that matches the argument name
-                log.i("%s", opt_alias)
+                log.i(f"{opt_alias}")
 
                 # Check whether this option was already found,
                 # if not, allocate a new list using this opt_alias
@@ -307,7 +316,7 @@ class ArgsParser:
                     bck = []
                     self._parsed[opt_alias] = bck
 
-                log.d("Returning bucket for %s", opt_alias)
+                log.d(f"Returning bucket for {opt_alias}")
 
                 return bck, option_spec
 
@@ -333,7 +342,7 @@ class ArgsParser:
                 param_ok_hook=param_ok_hook)
             return True
 
-        log.w("Unknown argument: '%s'", opt_alias)
+        log.w(f"Unknown argument: '{opt_alias}'")
         return False
 
     @staticmethod
@@ -351,11 +360,10 @@ class ArgsParser:
         at a certain point for some reason (e.g. don't consider an argument
         as an option parameter for variadic params if it is an option starting with -)
         """
-        log.d("Parsing and appending to bucket...\n"
-              "\t%s\n"
-              "\tparams = %s\n"
-              "\toffset = %d",
-              str(params_spec), params, params_offset)
+        log.d(f"Parsing and appending to bucket...\n"
+              f"\t{params_spec}\n"
+              f"\tparams = {params}\n"
+              f"\toffset = {params_offset}")
 
         param_cursor = 0
 
@@ -373,7 +381,7 @@ class ArgsParser:
 
         while param_cursor < params_spec.mandatory_count:
             param = params[params_offset + param_cursor]
-            log.d("[%d] Mandatory: checking validity: param_ok_hook('%s')", param_cursor, param)
+            log.d(f"[{param_cursor}] Mandatory: checking validity: param_ok_hook('{param}')")
 
             if not param_ok_hook(param):
                 raise ValueError("invalid parameter for feed argument '{}'".format(param))
@@ -392,7 +400,7 @@ class ArgsParser:
             if params_offset + param_cursor < len(params):
                 # There is this optional param, check if is valid
                 param = params[params_offset + param_cursor]
-                log.d("[%d] Optional: checking validity: param_ok_hook('%s')", param_cursor, param)
+                log.d(f"[{param_cursor}] Optional: checking validity: param_ok_hook('{param}')")
 
                 if not param_ok_hook(param):
                     log.d("Optional parameter not found; no problem")
@@ -403,8 +411,8 @@ class ArgsParser:
 
             param_cursor += 1
 
-        log.d("Parsing and appending to bucket (taking %d:%d)",
-              params_offset, params_offset + param_cursor)
+        log.d(f"Parsing and appending to bucket "
+              f"(taking {params_offset}:{params_offset + param_cursor})")
 
         # Provide the params to the parser, and add
         # the parsed value to the bucket
@@ -412,12 +420,12 @@ class ArgsParser:
             val = params_spec.parser(
                 params[params_offset:params_offset + param_cursor]
             )
-            log.i("> %s", "{}".format(val))
+            log.i(f"> {val}")
             bucket += list_wrap(val)
 
-        except:
+        except Exception as ex:
             log.w("Exception occurred while parsing optional argument; "
-                  "considering it as a different argument")
+                  f"considering it as a different argument: {ex}")
 
             return pre_optionals_param_cursor
 
@@ -457,13 +465,19 @@ class ArgsParser:
 class IntParams(OptionParams):
     def __init__(self, mandatory_count: int, optional_count: int = 0):
         super().__init__(mandatory_count, optional_count,
-                         lambda ps: [to_int(p, raise_exceptions=True) for p in ps])
+                         lambda ps: [to_int(p.strip(), raise_exceptions=True) for p in ps])
+
+
+class FloatParams(OptionParams):
+    def __init__(self, mandatory_count: int, optional_count: int = 0):
+        super().__init__(mandatory_count, optional_count,
+                         lambda ps: [to_float(p.strip(), raise_exceptions=True) for p in ps])
 
 
 class StrParams(OptionParams):
     def __init__(self, mandatory_count: int, optional_count: int = 0):
         super().__init__(mandatory_count, optional_count,
-                         lambda ps: ps)
+                         lambda ps: [p.strip() for p in ps])
 
 
 STR_PARAM = StrParams(1, 0)
@@ -472,6 +486,9 @@ STR_PARAM_OPT = StrParams(0, 1)
 INT_PARAM = IntParams(1, 0)
 INT_PARAM_OPT = IntParams(0, 1)
 
+FLOAT_PARAM = FloatParams(1, 0)
+FLOAT_PARAM_OPT = FloatParams(0, 1)
+
 PRESENCE_PARAM = OptionParams(0, 0, lambda ps: True)
 
 VARIADIC_PARAMS = StrParams(0, OptionParams.VARIADIC_PARAMETERS_COUNT)
@@ -481,7 +498,13 @@ VARIADIC_PARAMS = StrParams(0, OptionParams.VARIADIC_PARAMETERS_COUNT)
 # =============================================
 
 class ArgsSpec:
-    def parse(self, args: List[str]) -> Optional[Args]:
+    def parse(self, args: Union[str, List[str]]) -> Optional[Args]:
+        if is_str(args):
+            args = self.split_args(args)
+
+        if not is_list(args):
+            raise TypeError(f"args must be a list, found {type(args)}")
+
         return Args.parse(
             args=args,
             positionals_spec=self.positionals_spec(),
@@ -498,6 +521,9 @@ class ArgsSpec:
     def continue_parsing_hook(self) -> Optional[Callable[[str, ArgType, int, 'Args', List[str]], bool]]:
         return None
 
+    def split_args(self, args: str) -> List[str]:
+        return lexer.split(args)
+
 
 class PosArgsSpec(ArgsSpec):
     def __init__(self, mandatory: int, optional: int = 0):
@@ -536,4 +562,22 @@ class StopParseArgsSpec(ArgsSpec):
         return StrParams(self.mandatory, 0)
 
     def continue_parsing_hook(self) -> Optional[Callable[[str, ArgsSpec, int, 'Args', List[str]], bool]]:
-        return lambda arg, argtype, idx, parsedargs, positionals: len(positionals) < self.stop_after
\ No newline at end of file
+        return lambda arg, argtype, idx, parsedargs, positionals: len(positionals) < self.stop_after
+
+
+class KeepQuotesArgsSpec(ArgsSpec):
+    def split_args(self, args: str) -> List[str]:
+        return lexer.split(args, keepquotes=True)
+
+
+class KeyValArgsSpec(PosArgsSpec):
+    def __init__(self, optional: bool, *, keepquotes: bool):
+        super().__init__(
+            0 if optional else 2,
+            2 if optional else 0
+        )
+        self._keepquotes = keepquotes
+
+    def split_args(self, args: str) -> List[str]:
+        return [(part.strip("\"") if not self._keepquotes else part)
+                for part in args.split("=", maxsplit=1)]
