@@ -1,5 +1,5 @@
 from easyshare.sockets import SocketTcpOut
-from easyshare.utils.json import json_to_str
+from easyshare.utils.json import jtos
 import socket
 import ssl
 
@@ -10,7 +10,7 @@ if __name__ == "__main__":
         address="google.com", port=443, ssl_context=create_client_ssl_context()
     ).ssl_certificate()
     c1 = parse_cert_der(d1)
-    print(json_to_str(c1))
+    print(jtos(c1))
 
     # ----------
 
@@ -29,7 +29,7 @@ if __name__ == "__main__":
     # get certificate
     d2 = s.getpeercert(True)
     c2 = parse_cert_der(d2)
-    print(json_to_str(c2))
+    print(jtos(c2))
 
     assert c1 == c2
 
