@@ -1,17 +1,16 @@
 import os
 import pwd
-import shlex
 import pty
 
-# from ptyprocess import PtyProcessUnicode, PtyProcess
 import tty
 from select import select
 
+from easyshare.utils import lexer
 from easyshare.utils.os import user
 
 
 def pty_run(cmd = "/bin/sh"):
-    argv = shlex.split(cmd)
+    argv = lexer.split(cmd)
 
     master_read = pty._read
     stdin_read = pty._read
