@@ -1,6 +1,6 @@
 from easyshare.sockets import SocketUdpOut
 from easyshare.utils.net import get_primary_ip
-from easyshare.utils.types import str_to_bytes, bytes_to_str
+from easyshare.utils.types import stob, btos
 
 TO = (get_primary_ip(), 6666)
 s = SocketUdpOut()
@@ -10,7 +10,7 @@ while True:
 
     if outmsg == "recv":
         inmsgraw, endpoint = s.recv()
-        inmsg = bytes_to_str(inmsgraw)
+        inmsg = btos(inmsgraw)
         print("<< {} {}".format(inmsg, endpoint))
 
-    s.send(str_to_bytes(outmsg), TO[0], TO[1])
+    s.send(stob(outmsg), TO[0], TO[1])
