@@ -1,5 +1,5 @@
 from easyshare.sockets import SocketUdpIn
-from easyshare.utils.types import bytes_to_str, str_to_bytes
+from easyshare.utils.types import btos, stob
 
 s = SocketUdpIn(port=6666)
 
@@ -12,10 +12,10 @@ while True:
         print("Nothing received")
         continue
 
-    inmsg = bytes_to_str(inmsgraw)
+    inmsg = btos(inmsgraw)
     print("<< {} {}".format(inmsg, endpoint))
 
     if inmsg == "who":
         outmsg = __name__
         print(">> " + outmsg)
-        s.send(str_to_bytes(outmsg), endpoint[0], endpoint[1])
+        s.send(stob(outmsg), endpoint[0], endpoint[1])
