@@ -7,9 +7,10 @@ from easyshare.consts.net import ADDR_BROADCAST
 from easyshare.endpoint import Endpoint
 from easyshare.logging import get_logger
 from easyshare.protocol.types import ServerInfoFull
+from easyshare.settings import get_setting, Settings
 from easyshare.sockets import SocketUdpIn, SocketUdpOut
-from easyshare.tracing import trace_text, get_tracing_level, TRACING_TEXT
-from easyshare.utils.json import btoj, j
+from easyshare.tracing import trace_json, trace_text
+from easyshare.utils.json import btoj
 from easyshare.utils.types import itob
 
 log = get_logger(__name__)
@@ -23,14 +24,10 @@ class Discoverer:
 
     def __init__(
             self, *,
-            discover_port: int,
-            discover_timeout: int,
             response_handler: Callable[[Endpoint, ServerInfoFull], bool],
             discover_addr: str = ADDR_BROADCAST):
 
         self._discover_addr = discover_addr
-        self._discover_port = discover_port
-        self._discover_timeout = discover_timeout
         self._response_handler = response_handler
 
     def discover(self) -> bool:
@@ -39,31 +36,32 @@ class Discoverer:
         notifying the response_handler in the meanwhile.
         Returns True if the discover finished (timedout) or False if it has been stopped.
         """
+
+        discover_port = get_setting(Settings.DISCOVER_PORT)
+        discover_timeout = get_setting(Settings.DISCOVER_WAIT)
+
         discover_completed = True
 
         # Listening socket
         in_sock = SocketUdpIn()
 
-        log.i("Client discover port: %d", in_sock.port())
+        log.i(f"Client discover port: {in_sock.port()}")
 
         # Send discover
         discover_message = in_sock.port()
         discover_message_b = itob(discover_message, 2)
         out_sock = SocketUdpOut(broadcast=self._discover_addr == ADDR_BROADCAST)
 
-        log.i("Sending DISCOVER to %s:%d",
-              self._discover_addr,
-              self._discover_port)
+        log.i(f"Sending DISCOVER to {self._discover_addr}:{discover_port}")
 
-        if get_tracing_level() == TRACING_TEXT: # check for avoid json_pretty_str call
-            trace_text(
-                str(discover_message),
-                sender=out_sock.endpoint(), receiver=(self._discover_addr, self._discover_port),
-                direction=TransferDirection.OUT, protocol=TransferProtocol.UDP
-            )
+        trace_text(
+            str(discover_message),
+            sender=out_sock.endpoint(), receiver=(self._discover_addr, discover_port),
+            direction=TransferDirection.OUT, protocol=TransferProtocol.UDP
+        )
 
-        out_sock.send(discover_message_b, self._discover_addr, self._discover_port,
-                      trace=get_tracing_level() > TRACING_TEXT)
+        out_sock.send(discover_message_b, self._discover_addr, discover_port,
+                      trace=False)
 
         # Listen
         discover_start_time = datetime.now()
@@ -71,11 +69,11 @@ class Discoverer:
         while True:
             # Calculate remaining time
             remaining_seconds = \
-                self._discover_timeout - (datetime.now() - discover_start_time).total_seconds()
+                discover_timeout - (datetime.now() - discover_start_time).total_seconds()
 
             if remaining_seconds < 0:
                 # No more time to wait
-                log.i("DISCOVER timeout elapsed (%.3f)", self._discover_timeout)
+                log.i("DISCOVER timeout elapsed (%.3f)", discover_timeout)
                 break
 
             log.i("Waiting for %.3f seconds...", remaining_seconds)
@@ -88,17 +86,16 @@ class Discoverer:
 
             # Ready for recv
             log.d("DISCOVER socket ready for recv")
-            raw_resp, endpoint = in_sock.recv(trace=get_tracing_level() > TRACING_TEXT)
+            raw_resp, endpoint = in_sock.recv(trace=False)
 
-            log.i("Received DISCOVER response from: %s", endpoint)
+            log.i(f"Received DISCOVER response from: {endpoint}")
             resp: ServerInfoFull = cast(ServerInfoFull, btoj(raw_resp))
 
-            if get_tracing_level() == TRACING_TEXT:  # check for avoid json_pretty_str call
-                trace_text(
-                    j(resp),
-                    sender=in_sock.endpoint(), receiver=endpoint,
-                    direction=TransferDirection.IN, protocol=TransferProtocol.UDP
-                )
+            trace_json(
+                resp,
+                sender=in_sock.endpoint(), receiver=endpoint,
+                direction=TransferDirection.IN, protocol=TransferProtocol.UDP
+            )
 
             # Dispatch the response and check whether go on on listening
             go_ahead = self._response_handler(endpoint, resp)
