@@ -5,6 +5,7 @@ from enum import Enum
 from typing import Tuple
 
 from easyshare.common import easyshare_setup
+from easyshare.consts import ansi
 from easyshare.logging import get_logger
 from easyshare.styling import fg
 from easyshare.utils.env import is_unicode_supported
@@ -197,9 +198,8 @@ class Progressor(ABC):
             # The \r at the end is needed if something else is printed during
             # the progress (so that it will overwrite the bar, and we will render
             # it again the next iter)
-            # DELETE_EOL could be used, but \r seems to work as well
-            # (since we write always a full line)
-            print("\r" + progress_line, end="" if inline else "\n", flush=True)
+            # \r should work as well (since we write always a full line)
+            print(ansi.RESET_LINE + progress_line, end="" if inline else "\n", flush=True)
 
     def __enter__(self):
         return self
